@@ -51,7 +51,9 @@ def DNSLookup(name,qtype,strict=True,timeout=None):
         continue
       # keep test zonedata human readable, but translate to simulate pydns
       if t == 'AAAA':
-        v = spf.inet_pton(v)
+        v = bytes(socket.inet_pton(socket.AF_INET6,v))
+      elif t in ('TXT','SPF'):
+        v = tuple([s.encode('utf-8') for s in v])
       yield ((name,t),v)
   except KeyError:
     if name.startswith('error.'):
@@ -214,7 +216,7 @@ if __name__ == '__main__':
     if not tc:
       tc = SPFTestCase()
       t = loadYAML('rfc4408-tests.yml')
-      if not t.has_key(i):
+      if i not in t:
         t = loadYAML('test.yml')
     tc.runTest([t[i]])
   if not tc:
@@ -222,6 +224,6 @@ if __name__ == '__main__':
     try:
       zonedata = loadZone(next(yaml.safe_load_all(fp)))
     finally: fp.close()
-    #print zonedata
+    #print(zonedata)
     suite = suite()
     unittest.TextTestRunner().run(suite)
